@@ -1,3 +1,22 @@
+/*
+(C) Copyright 2015 Jeremy Burton
+
+This file is part of Sark-100-antenna-analyzer.
+
+Sark-100-antenna-analyzer is free software: you can redistribute it
+and/or modify it under the terms of the GNU General Public License as
+published by the Free Software Foundation, either version 3 of the
+License, or (at your option) any later version.
+
+Sark-100-antenna-analyzerr is distributed in the hope that it will be
+useful, but WITHOUT ANY WARRANTY; without even the implied warranty
+of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
+*/
+
 #include <math.h>
 #include <stdio.h>
 
@@ -151,10 +170,12 @@ void GraphScale::SetIncAuto()
 {
     double n,span=this->vmax-this->vmin;
     n = pow(10.0,floor(log10(span)));
-    if (span<=n) { this->vinc=n/10.0; return; } else n*=2.0;
-    if (span<=n) { this->vinc=n/10.0; return; } else n*=2.5;
-    if (span<=n) { this->vinc=n/10.0; return; } else n*=2;
+    if (span<=n) { this->vinc=n/10.0; goto done; } else n*=2.0;
+    if (span<=n) { this->vinc=n/10.0; goto done; } else n*=2.5;
+    if (span<=n) { this->vinc=n/10.0; goto done; } else n*=2;
     this->vinc=n/10.0;
+done:
+    if (this->vinc==0.0) vinc=1.0; //Safty setting for vinc to prevent infinite loop / dev by 0 downstream.
 }
 
 void GraphScale::Expand(double min,double max)
