@@ -1,4 +1,24 @@
+/*
+(C) Copyright 2015 Jeremy Burton
+
+This file is part of Sark-100-antenna-analyzer.
+
+Sark-100-antenna-analyzer is free software: you can redistribute it
+and/or modify it under the terms of the GNU General Public License as
+published by the Free Software Foundation, either version 3 of the
+License, or (at your option) any later version.
+
+Sark-100-antenna-analyzer is distributed in the hope that it will be
+useful, but WITHOUT ANY WARRANTY; without even the implied warranty
+of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
+*/
+
 #include <stdio.h>
+#include <locale.h>
 
 #include <QDir>
 #include <QFileDialog>
@@ -13,7 +33,7 @@
 #include "ui_mainwindow.h"
 
 const Version
-    MainWindow::version = Version(0,9,9,"");
+    MainWindow::version = Version(0,10,13,"");
 
 ScanData scandata;
 
@@ -22,7 +42,12 @@ MainWindow::MainWindow(QWidget *parent) :
     ui(new Ui::MainWindow)
 {
 setlinebuf(stdout);
-
+//{
+//char *p;
+//printf("setlocale=%p\n",p=setlocale(LC_ALL, "sv_SE.UTF-8"));
+//if (p) printf("\t%s\n",p);
+//std::setlocale(LC_ALL, "sv_SE");
+//}
     Config::read();
 
     ui->setupUi(this);
@@ -52,24 +77,36 @@ setlinebuf(stdout);
     connect(ui->fspan, SIGNAL(valueChanged(double)), this, SLOT(Slot_fspan_change(double)));
     connect(ui->point_count, SIGNAL(valueChanged(int)), this, SLOT(Slot_point_count_change(int)));
 
+    connect(ui->monStartBtn,SIGNAL(clicked()),this,SLOT(Slot_monStart_click()));
+    connect(ui->monStopBtn,SIGNAL(clicked()),this,SLOT(Slot_monStop_click()));
+
     QCheckBox *ctrls[] = {ui->plotz_chk,ui->plotx_chk,ui->plotr_chk,NULL};
     for (int i=0; ctrls[i]; i++)
         connect(ctrls[i], SIGNAL(stateChanged(int)), this, SLOT(Slot_plot_change(int)));
 
     link = new SerialLink("/dev/ttyUSB0",57600);
     if (link->IsUp())
-        link->Cmd_Off(this);
+        link->Cmd_Off();
 
     ui->band_cb->setCurrentIndex(16);
 
     ui->scan_data->setHorizontalHeaderLabels(QStringList() << "freq" << "SWR" << "Z" << "R" << "X");
 
+#ifdef ENABLE_TEST_DATA
     Slot_scanDummyBtn_click();
+#else
+    ui->scanDummyBtn->setVisible(false);
+#endif
 
     ui->canvas1->cursor = ui->cursor;
 
     ui->tabWidget->setCurrentIndex(1);
-    ui->tabWidget->setTabEnabled(0,false);
+    //ui->tabWidget->setTabEnabled(0,false);
+
+    montimer.setParent(this);
+    connect(&montimer, SIGNAL(timeout()), this, SLOT(Slot_montimer_timeout()));
+
+//std::setlocale(LC_ALL, "sv_SE.UTF-8");
 }
 
 
@@ -85,6 +122,7 @@ void MainWindow::RaiseEvent(event_t event,int arg)
     {
       case progress_event:
         ui->progressBar->setValue(arg);
+        //draw_graph1();
         break;
     }
 }
@@ -129,7 +167,6 @@ void MainWindow::draw_graph1()
     //if (ui->canvas1->xtrace->enabled && scandata.points[scandata.X_max_idx].X>scale->vmax) scale->vmax=scandata.points[scandata.X_max_idx].X;
     if (ui->canvas1->xtrace->enabled) scale->Expand(scandata.points[scandata.X_min_idx].X,scandata.points[scandata.X_max_idx].X);
     if (ui->canvas1->rtrace->enabled && scandata.points[scandata.R_max_idx].R>scale->vmax) scale->vmax=scandata.points[scandata.R_max_idx].R;
-    //if (ui->canvas1->x2trace->enabled && scandata.points[scandata.X2_min_idx].X2<scale->vmin) scale->vmin=scandata.points[scandata.X2_min_idx].X2;
     if (scale->vmax==0.0) scale->vmax=1.0;
     scale->SetIncAuto();
     scale->SetMinAuto();
@@ -146,10 +183,6 @@ void MainWindow::draw_graph1()
     for (unsigned int i=0;i<scandata.points.size();i++)
         ui->canvas1->xtrace->points[i] = scandata.points[i].X;
 
-//    ui->canvas1->x2trace->points.resize(scandata.points.size());
-//    for (unsigned int i=0;i<scandata.points.size();i++)
-//        ui->canvas1->x2trace->points[i] = scandata.points[i].X2;
-
     ui->canvas1->rtrace->points.resize(scandata.points.size());
     for (unsigned int i=0;i<scandata.points.size();i++)
         ui->canvas1->rtrace->points[i] = scandata.points[i].R;
@@ -183,13 +216,14 @@ void MainWindow::Slot_scanBtn_click()
                   (long)((scandata.freq_end-scandata.freq_start)/scandata.GetPointCount()),
                   ui->useraw_chk->checkState()==Qt::Checked,
                   this);
-        link->Cmd_Off(this);
+        link->Cmd_Off();
     }
 
     populate_table();
     draw_graph1();
 }
 
+#ifdef ENABLE_TEST_DATA
 void MainWindow::Slot_scanDummyBtn_click()
 {
     scandata.freq_start = (ui->fcentre->value()-ui->fspan->value()/2.0)*1000000;
@@ -201,11 +235,17 @@ void MainWindow::Slot_scanDummyBtn_click()
     populate_table();
     draw_graph1();
 }
+#endif
 
 void MainWindow::Slot_cursor_move(double pos)
 {
 //printf("pos=%lf\n",pos);
-    Sample *sample = &scandata.points[pos*(double)(scandata.points.size()-1)];
+    int n = pos*(double)(scandata.points.size()-1);
+
+    if (n<0 || n>=scandata.GetPointCount())
+        return;
+
+    Sample *sample = &scandata.points[n];
 
     ui->cursor_disp->setText(QString("f=%1MHz, swr=%2, Z=%3%4")
             .arg(sample->freq/1000000)
@@ -294,7 +334,6 @@ void MainWindow::Slot_plot_change(int)
 {
     ui->canvas1->ztrace->enabled = ui->plotz_chk->checkState()==Qt::Checked;
     ui->canvas1->xtrace->enabled = ui->plotx_chk->checkState()==Qt::Checked;
-    //ui->canvas1->x2trace->enabled = ui->plotx2_chk->checkState()==Qt::Checked;
     ui->canvas1->rtrace->enabled = ui->plotr_chk->checkState()==Qt::Checked;
     draw_graph1();
 //    ui->canvas1->update();
@@ -433,7 +472,7 @@ void MainWindow::Slot_menuDevice_Select(QAction *act)
   link = new SerialLink(QString("/dev/" + act->text()).toLatin1().data(),57600);
 
   if (link->IsUp())
-      link->Cmd_Off(this);
+      link->Cmd_Off();
 }
 
 void MainWindow::Slot_about()
@@ -469,3 +508,72 @@ void MainWindow::Slot_copy()
 
   qApp->clipboard()->setText(txt);
 }
+
+void MainWindow::Slot_monStart_click()
+{
+    ui->SWR_Bar->vmin = ui->SWR_Bar->vorig = 1;
+    ui->SWR_Bar->vmax = 10;
+    ui->SWR_Bar->SetIncAuto();
+    ui->SWR_Bar->value = 1;
+
+    ui->Z_Bar->brush = QBrush(qRgb(255,85,0));
+    ui->Z_Bar->vmin = 0;
+    ui->Z_Bar->vmax = 200;
+    ui->Z_Bar->value = 50;
+    ui->Z_Bar->SetIncAuto();
+
+    ui->R_Bar->brush = QBrush(Qt::darkGreen);
+    ui->R_Bar->vmin = 0;
+    ui->R_Bar->vmax = 200;
+    ui->R_Bar->value = 50;
+    ui->R_Bar->SetIncAuto();
+
+    ui->X_Bar->brush = QBrush(Qt::red);
+    ui->X_Bar->vmin = -100;
+    ui->X_Bar->vmax = 200;
+    ui->X_Bar->value = 0;
+    ui->X_Bar->SetIncAuto();
+
+    if (link->IsUp())
+    {
+        link->Cmd_Freq((long)(ui->monfreq->value()*1000000));
+        link->Cmd_On();
+    }
+
+    Slot_montimer_timeout();
+    montimer.start((long)(ui->monrate->value()));
+}
+
+void MainWindow::Slot_monStop_click()
+{
+    montimer.stop();
+
+    if (link->IsUp())
+        link->Cmd_Off();
+}
+
+void MainWindow::Slot_montimer_timeout()
+{
+    Sample sample;
+
+    if (link->IsUp())
+    {
+        link->Cmd_Raw(sample);
+
+        ui->SWR_lbl->setText(QString("%1:1").arg(sample.swr, 0,'f',1));
+        ui->SWR_Bar->value = sample.swr;
+        ui->SWR_Bar->update();
+
+        ui->Z_lbl->setText(QString("%1").arg(sample.Z, 0,'f',1));
+        ui->Z_Bar->value = sample.Z;
+        ui->Z_Bar->update();
+
+        ui->R_lbl->setText(QString("%1").arg(sample.R, 0,'f',1));
+        ui->R_Bar->value = sample.R;
+        ui->R_Bar->update();
+
+        ui->X_lbl->setText(QString("%1").arg(sample.X, 0,'f',1));
+        ui->X_Bar->value = sample.X;
+        ui->X_Bar->update();
+    }
+}
